@@ -22,6 +22,7 @@ pub struct RequestArgs {
     pub is_shutdown: Option<Arc<AtomicBool>>,
     pub diagnostics_key: Option<KeyType>,
     pub proxy_config: Option<ProxyConfig>,
+    pub disable_file_streaming: Option<bool>,
 }
 
 impl Default for RequestArgs {
@@ -44,6 +45,7 @@ impl RequestArgs {
             is_shutdown: None,
             diagnostics_key: None,
             proxy_config: None,
+            disable_file_streaming: None,
         }
     }
 
@@ -88,7 +90,6 @@ pub struct Response {
     pub status_code: Option<u16>,
     pub data: Option<ResponseData>,
     pub error: Option<String>,
-    pub headers: Option<HashMap<String, String>>,
 }
 
 #[derive(PartialEq, Clone)]
@@ -102,37 +103,63 @@ pub trait NetworkProvider: Sync + Send {
     async fn send(&self, method: &HttpMethod, args: &RequestArgs) -> Response;
 }
 
-pub trait ResponseDataStream: std::io::Read + std::io::Seek + Send + Sync {}
+pub trait ResponseDataStream:
+    std::io::Read + std::io::Seek + std::fmt::Debug + Send + Sync
+{
+}
 
-impl<T: std::io::Read + std::io::Seek + Send + Sync> ResponseDataStream for T {}
+impl<T: std::io::Read + std::io::Seek + std::fmt::Debug + Send + Sync> ResponseDataStream for T {}
 
 pub struct ResponseData {
     stream: Box<dyn ResponseDataStream>,
+    headers: Option<HashMap<String, String>>,
 }
 
-const RESPONSE_DATA_TAG: &str = "ResponseData";
+const TAG: &str = "ResponseData";
 
 impl ResponseData {
     pub fn from_bytes(bytes: Vec<u8>) -> Self {
+        Self::from_bytes_with_headers(bytes, None)
+    }
+
+    pub fn from_bytes_with_headers(
+        bytes: Vec<u8>,
+        headers: Option<HashMap<String, String>>,
+    ) -> Self {
         Self {
             stream: Box::new(Cursor::new(bytes)),
+            headers,
         }
     }
 
     pub fn from_stream(stream: Box<dyn ResponseDataStream>) -> Self {
-        Self { stream }
+        Self::from_stream_with_headers(stream, None)
     }
 
-    pub fn get_stream_ref(&mut self) -> &mut Box<dyn ResponseDataStream> {
+    pub fn from_stream_with_headers(
+        stream: Box<dyn ResponseDataStream>,
+        headers: Option<HashMap<String, String>>,
+    ) -> Self {
+        Self { stream, headers }
+    }
+
+    pub fn get_stream_ref(&self) -> &dyn ResponseDataStream {
+        &self.stream
+    }
+
+    pub fn get_stream_mut(&mut self) -> &mut dyn ResponseDataStream {
         &mut self.stream
     }
 
+    pub fn get_header_ref(&self, key: &str) -> Option<&String> {
+        self.headers.as_ref().and_then(|h| h.get(key))
+    }
+
     pub fn deserialize_into<T: DeserializeOwned>(&mut self) -> Result<T, StatsigErr> {
         self.rewind()?;
 
-        let result = serde_json::from_reader(self.stream.as_mut()).map_err(|e| {
-            StatsigErr::JsonParseError(RESPONSE_DATA_TAG.to_string(), e.to_string())
-        })?;
+        let result = serde_json::from_reader(self.stream.as_mut())
+            .map_err(|e| StatsigErr::JsonParseError(TAG.to_string(), e.to_string()))?;
 
         Ok(result)
     }
@@ -146,7 +173,7 @@ impl ResponseData {
         let mut deserializer = serde_json::Deserializer::from_reader(self.stream.as_mut());
 
         T::deserialize_in_place(&mut deserializer, place)
-            .map_err(|e| StatsigErr::JsonParseError(RESPONSE_DATA_TAG.to_string(), e.to_string()))
+            .map_err(|e| StatsigErr::JsonParseError(TAG.to_string(), e.to_string()))
     }
 
     pub fn read_to_string(&mut self) -> Result<String, StatsigErr> {
@@ -159,7 +186,7 @@ impl ResponseData {
             .map_err(|e| StatsigErr::SerializationError(e.to_string()))?;
 
         String::from_utf8(buf)
-            .map_err(|e| StatsigErr::JsonParseError(RESPONSE_DATA_TAG.to_string(), e.to_string()))
+            .map_err(|e| StatsigErr::JsonParseError(TAG.to_string(), e.to_string()))
     }
 
     fn rewind(&mut self) -> Result<(), StatsigErr> {
