@@ -7,3 +7,6 @@ pub mod proxy_config;
 pub use http_types::*;
 pub use network_client::*;
 pub use network_error::*;
+
+#[cfg(test)]
+mod __tests__;
