@@ -144,6 +144,29 @@ impl Statsig {
         });
     }
 
+    #[cfg(feature = "ffi-support")]
+    pub(crate) fn emit_gate_evaluated_parts(
+        &self,
+        gate_name: &str,
+        reason: &str,
+        eval_result: Option<&crate::evaluation::evaluator_result::EvaluatorResult>,
+    ) {
+        let mut rule_id = None;
+        let mut value = false;
+
+        if let Some(eval) = eval_result {
+            rule_id = eval.rule_id.as_ref().map(|r| r.as_str());
+            value = eval.bool_value;
+        }
+
+        self.emit(SdkEvent::GateEvaluated {
+            gate_name,
+            rule_id: rule_id.unwrap_or_default(),
+            value,
+            reason,
+        });
+    }
+
     pub(crate) fn emit_dynamic_config_evaluated(&self, config: &DynamicConfig) {
         self.emit(SdkEvent::DynamicConfigEvaluated {
             config_name: config.name.as_str(),
@@ -153,12 +176,62 @@ impl Statsig {
         });
     }
 
+    #[cfg(feature = "ffi-support")]
+    pub(crate) fn emit_dynamic_config_evaluated_parts(
+        &self,
+        config_name: &str,
+        reason: &str,
+        eval_result: Option<&crate::evaluation::evaluator_result::EvaluatorResult>,
+    ) {
+        let mut rule_id = None;
+        let mut value = None;
+
+        if let Some(eval) = eval_result {
+            rule_id = eval.rule_id.as_ref().map(|r| r.as_str());
+            value = eval.json_value.as_ref();
+        }
+
+        self.emit(SdkEvent::DynamicConfigEvaluated {
+            config_name,
+            reason,
+            rule_id,
+            value,
+        });
+    }
+
     pub(crate) fn emit_experiment_evaluated(&self, experiment: &Experiment) {
         self.emit(SdkEvent::ExperimentEvaluated {
             experiment_name: experiment.name.as_str(),
             reason: experiment.details.reason.as_str(),
             rule_id: Some(experiment.rule_id.as_str()),
             value: experiment.__evaluation.as_ref().map(|e| &e.value),
+            group_name: experiment.group_name.as_deref(),
+        });
+    }
+
+    #[cfg(feature = "ffi-support")]
+    pub(crate) fn emit_experiment_evaluated_parts(
+        &self,
+        experiment_name: &str,
+        reason: &str,
+        eval_result: Option<&crate::evaluation::evaluator_result::EvaluatorResult>,
+    ) {
+        let mut rule_id = None;
+        let mut value = None;
+        let mut group_name = None;
+
+        if let Some(eval) = eval_result {
+            rule_id = eval.rule_id.as_ref().map(|r| r.as_str());
+            value = eval.json_value.as_ref();
+            group_name = eval.group_name.as_ref().map(|g| g.as_str());
+        }
+
+        self.emit(SdkEvent::ExperimentEvaluated {
+            experiment_name,
+            reason,
+            rule_id,
+            value,
+            group_name,
         });
     }
 
@@ -169,4 +242,24 @@ impl Statsig {
             rule_id: Some(layer.rule_id.as_str()),
         });
     }
+
+    #[cfg(feature = "ffi-support")]
+    pub(crate) fn emit_layer_evaluated_parts(
+        &self,
+        layer_name: &str,
+        reason: &str,
+        eval_result: Option<&crate::evaluation::evaluator_result::EvaluatorResult>,
+    ) {
+        let mut rule_id = None;
+
+        if let Some(eval) = eval_result {
+            rule_id = eval.rule_id.as_ref().map(|r| r.as_str());
+        }
+
+        self.emit(SdkEvent::LayerEvaluated {
+            layer_name,
+            reason,
+            rule_id,
+        });
+    }
 }
