@@ -44,6 +44,8 @@ use crate::sdk_diagnostics::marker::{ActionType, KeyType, Marker};
 use crate::sdk_event_emitter::SdkEventEmitter;
 use crate::spec_store::{SpecStore, SpecStoreData};
 use crate::specs_adapter::{StatsigCustomizedSpecsAdapter, StatsigHttpSpecsAdapter};
+use crate::specs_response::spec_types::Rule;
+use crate::specs_response::specs_hash_map::SpecPointer;
 use crate::statsig_err::StatsigErr;
 use crate::statsig_metadata::StatsigMetadata;
 use crate::statsig_options::StatsigOptions;
@@ -1129,6 +1131,41 @@ impl Statsig {
         self.spec_store
             .get_fields_used_for_entity(gate_name, SpecType::Gate)
     }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn get_raw_feature_gate_with_options(
+        &self,
+        user: &StatsigUser,
+        gate_name: &str,
+        options: FeatureGateEvaluationOptions,
+    ) -> String {
+        use crate::evaluation::evaluator_result::result_to_gate_raw;
+
+        let interned_gate_name = InternedString::from_str_ref(gate_name);
+        let user_internal = self.internalize_user(user);
+
+        let (details, evaluation) =
+            self.evaluate_spec_raw(&user_internal, gate_name, &SpecType::Gate, None);
+
+        let raw = result_to_gate_raw(gate_name, &details, evaluation.as_ref());
+
+        self.emit_gate_evaluated_parts(gate_name, details.reason.as_str(), evaluation.as_ref());
+
+        if options.disable_exposure_logging {
+            log_d!(TAG, "Exposure logging is disabled for gate {}", gate_name);
+            self.event_logger.increment_non_exposure_checks(gate_name);
+        } else {
+            self.event_logger.enqueue(EnqueueExposureOp::gate_exposure(
+                &user_internal,
+                &interned_gate_name,
+                ExposureTrigger::Auto,
+                details,
+                evaluation,
+            ));
+        }
+
+        raw
+    }
 }
 
 // ------------------------------------------------------------------------------- [ Dynamic Config ]
@@ -1211,6 +1248,56 @@ impl Statsig {
         self.spec_store
             .get_fields_used_for_entity(config_name, SpecType::DynamicConfig)
     }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn get_raw_dynamic_config_with_options(
+        &self,
+        user: &StatsigUser,
+        dynamic_config_name: &str,
+        options: DynamicConfigEvaluationOptions,
+    ) -> String {
+        use crate::evaluation::evaluator_result::result_to_dynamic_config_raw;
+
+        let interned_dynamic_config_name = InternedString::from_str_ref(dynamic_config_name);
+        let user_internal = self.internalize_user(user);
+        let disable_exposure_logging: bool = options.disable_exposure_logging;
+
+        let (details, evaluation) = self.evaluate_spec_raw(
+            &user_internal,
+            dynamic_config_name,
+            &SpecType::DynamicConfig,
+            Some(disable_exposure_logging),
+        );
+
+        let raw = result_to_dynamic_config_raw(dynamic_config_name, &details, evaluation.as_ref());
+
+        self.emit_dynamic_config_evaluated_parts(
+            dynamic_config_name,
+            details.reason.as_str(),
+            evaluation.as_ref(),
+        );
+
+        if disable_exposure_logging {
+            log_d!(
+                TAG,
+                "Exposure logging is disabled for Dynamic Config {}",
+                dynamic_config_name
+            );
+            self.event_logger
+                .increment_non_exposure_checks(dynamic_config_name);
+        } else {
+            self.event_logger
+                .enqueue(EnqueueExposureOp::dynamic_config_exposure(
+                    &user_internal,
+                    &interned_dynamic_config_name,
+                    ExposureTrigger::Auto,
+                    details,
+                    evaluation,
+                ));
+        }
+
+        raw
+    }
 }
 
 // ------------------------------------------------------------------------------- [ Experiment ]
@@ -1237,11 +1324,13 @@ impl Statsig {
             experiment_name,
             Some(options.disable_exposure_logging),
         );
-        if let Some(persisted_experiment) = self.persistent_values_manager.as_ref().and_then(|m| {
-            m.try_apply_sticky_value_to_experiment(&user_internal, &options, &experiment)
-        }) {
-            experiment = persisted_experiment
-        }
+
+        experiment = PersistentValuesManager::try_apply_sticky_value_to_experiment(
+            &self.persistent_values_manager,
+            &user_internal,
+            &options,
+            experiment,
+        );
 
         if disable_exposure_logging {
             log_d!(
@@ -1291,6 +1380,175 @@ impl Statsig {
         experiment_name: &str,
         group_name: &str,
     ) -> Experiment {
+        self.get_experiment_by_group_name_impl(
+            experiment_name,
+            group_name,
+            |spec_pointer, rule, details| {
+                if let (Some(spec_pointer), Some(rule)) = (spec_pointer, rule) {
+                    let value = rule.return_value.get_json().unwrap_or_default();
+                    let rule_id = String::from(rule.id.as_str());
+                    let id_type = rule.id_type.value.unperformant_to_string();
+                    let group_name = rule.group_name.as_ref().map(|g| g.unperformant_to_string());
+
+                    return Experiment {
+                        name: experiment_name.to_string(),
+                        value,
+                        rule_id,
+                        id_type,
+                        group_name,
+                        details,
+                        is_experiment_active: spec_pointer.inner.is_active.unwrap_or(false),
+                        __evaluation: None,
+                    };
+                }
+
+                make_experiment(experiment_name, None, details)
+            },
+        )
+    }
+
+    pub fn get_experiment_by_group_id_advanced(
+        &self,
+        experiment_name: &str,
+        group_id: &str,
+    ) -> Experiment {
+        self.get_experiment_by_group_id_advanced_impl(
+            experiment_name,
+            group_id,
+            |spec_pointer, rule, details| {
+                if let (Some(spec_pointer), Some(rule)) = (spec_pointer, rule) {
+                    let value = rule.return_value.get_json().unwrap_or_default();
+                    let rule_id = String::from(rule.id.as_str());
+                    let id_type = rule.id_type.value.unperformant_to_string();
+                    let group_name = rule.group_name.as_ref().map(|g| g.unperformant_to_string());
+
+                    return Experiment {
+                        name: experiment_name.to_string(),
+                        value,
+                        rule_id,
+                        id_type,
+                        group_name,
+                        details,
+                        is_experiment_active: spec_pointer.inner.is_active.unwrap_or(false),
+                        __evaluation: None,
+                    };
+                }
+
+                make_experiment(experiment_name, None, details)
+            },
+        )
+    }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn get_raw_experiment_by_group_name(
+        &self,
+        experiment_name: &str,
+        group_name: &str,
+    ) -> String {
+        use crate::evaluation::evaluator_result::rule_to_experiment_raw;
+
+        self.get_experiment_by_group_name_impl(
+            experiment_name,
+            group_name,
+            |spec_pointer, rule, details| {
+                rule_to_experiment_raw(experiment_name, spec_pointer, rule, details)
+            },
+        )
+    }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn get_raw_experiment_with_options(
+        &self,
+        user: &StatsigUser,
+        experiment_name: &str,
+        options: ExperimentEvaluationOptions,
+    ) -> String {
+        use crate::evaluation::evaluator_result::result_to_experiment_raw;
+
+        let interned_experiment_name = InternedString::from_str_ref(experiment_name);
+        let user_internal = self.internalize_user(user);
+        let disable_exposure_logging: bool = options.disable_exposure_logging;
+
+        let (details, result) = self.evaluate_spec_raw(
+            &user_internal,
+            experiment_name,
+            &SpecType::Experiment,
+            Some(disable_exposure_logging),
+        );
+
+        let (result, details) = PersistentValuesManager::try_apply_sticky_value_to_raw_experiment(
+            &self.persistent_values_manager,
+            &user_internal,
+            &options,
+            details,
+            result,
+        );
+
+        let raw = result_to_experiment_raw(experiment_name, &details, result.as_ref());
+
+        self.emit_experiment_evaluated_parts(
+            experiment_name,
+            details.reason.as_str(),
+            result.as_ref(),
+        );
+
+        if disable_exposure_logging {
+            log_d!(
+                TAG,
+                "Exposure logging is disabled for Experiment {}",
+                experiment_name
+            );
+            self.event_logger
+                .increment_non_exposure_checks(experiment_name);
+        } else {
+            self.event_logger
+                .enqueue(EnqueueExposureOp::dynamic_config_exposure(
+                    &user_internal,
+                    &interned_experiment_name,
+                    ExposureTrigger::Auto,
+                    details,
+                    result,
+                ));
+        }
+
+        raw
+    }
+
+    fn get_experiment_by_group_name_impl<T>(
+        &self,
+        experiment_name: &str,
+        group_name: &str,
+        result_factory: impl FnOnce(Option<&SpecPointer>, Option<&Rule>, EvaluationDetails) -> T,
+    ) -> T {
+        self.get_experiment_by_rule_match_impl(
+            experiment_name,
+            |rule| rule.group_name.as_deref() == Some(group_name),
+            result_factory,
+        )
+    }
+
+    fn get_experiment_by_group_id_advanced_impl<T>(
+        &self,
+        experiment_name: &str,
+        rule_id: &str,
+        result_factory: impl FnOnce(Option<&SpecPointer>, Option<&Rule>, EvaluationDetails) -> T,
+    ) -> T {
+        self.get_experiment_by_rule_match_impl(
+            experiment_name,
+            |rule| rule.id.as_str() == rule_id,
+            result_factory,
+        )
+    }
+
+    fn get_experiment_by_rule_match_impl<T, P>(
+        &self,
+        experiment_name: &str,
+        rule_predicate: P,
+        result_factory: impl FnOnce(Option<&SpecPointer>, Option<&Rule>, EvaluationDetails) -> T,
+    ) -> T
+    where
+        P: Fn(&Rule) -> bool,
+    {
         let data = read_lock_or_else!(self.spec_store.data, {
             log_error_to_statsig_and_console!(
                 self.ops_stats.clone(),
@@ -1299,8 +1557,8 @@ impl Statsig {
                     "Failed to acquire read lock for spec store data".to_string()
                 )
             );
-            return make_experiment(
-                experiment_name,
+            return result_factory(
+                None,
                 None,
                 EvaluationDetails::error("Failed to acquire read lock for spec store data"),
             );
@@ -1310,8 +1568,8 @@ impl Statsig {
         let experiment = data.values.dynamic_configs.get(&experiment_name);
 
         let Some(exp) = experiment else {
-            return make_experiment(
-                experiment_name.as_str(),
+            return result_factory(
+                None,
                 None,
                 EvaluationDetails::unrecognized(
                     &data.source,
@@ -1321,35 +1579,20 @@ impl Statsig {
             );
         };
 
-        if let Some(rule) = exp
-            .inner
-            .rules
-            .iter()
-            .find(|rule| rule.group_name.as_deref() == Some(group_name))
-        {
-            let value = rule.return_value.get_json().unwrap_or_default();
-            let rule_id = String::from(rule.id.as_str());
-            let id_type = rule.id_type.value.unperformant_to_string();
-            let group_name = rule.group_name.as_ref().map(|g| g.unperformant_to_string());
-
-            return Experiment {
-                name: experiment_name.to_string(),
-                value,
-                rule_id,
-                id_type,
-                group_name,
-                details: EvaluationDetails::recognized_without_eval_result(
+        if let Some(rule) = exp.inner.rules.iter().find(|rule| rule_predicate(rule)) {
+            return result_factory(
+                Some(exp),
+                Some(rule),
+                EvaluationDetails::recognized_without_eval_result(
                     &data.source,
                     data.values.time,
                     data.time_received_at,
                 ),
-                is_experiment_active: exp.inner.is_active.unwrap_or(false),
-                __evaluation: None,
-            };
+            );
         }
 
-        make_experiment(
-            experiment_name.as_str(),
+        result_factory(
+            None,
             None,
             EvaluationDetails::unrecognized(&data.source, data.values.time, data.time_received_at),
         )
@@ -1400,6 +1643,81 @@ impl Statsig {
         self.spec_store
             .get_fields_used_for_entity(layer_name, SpecType::Layer)
     }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn get_raw_layer_with_options(
+        &self,
+        user: &StatsigUser,
+        layer_name: &str,
+        options: LayerEvaluationOptions,
+    ) -> String {
+        use crate::evaluation::evaluator_result::result_to_layer_raw;
+
+        let user_internal = self.internalize_user(user);
+        let disable_exposure_logging: bool = options.disable_exposure_logging;
+
+        let (details, result) = self.evaluate_spec_raw(
+            &user_internal,
+            layer_name,
+            &SpecType::Layer,
+            Some(disable_exposure_logging),
+        );
+
+        let (result, details) = PersistentValuesManager::try_apply_sticky_value_to_raw_layer(
+            &self.persistent_values_manager,
+            &user_internal,
+            &options,
+            &self.spec_store,
+            &self.ops_stats,
+            details,
+            result,
+        );
+
+        let raw = result_to_layer_raw(
+            &user_internal,
+            layer_name,
+            options,
+            &details,
+            result.as_ref(),
+        );
+
+        self.emit_layer_evaluated_parts(layer_name, details.reason.as_str(), result.as_ref());
+
+        if disable_exposure_logging {
+            log_d!(TAG, "Exposure logging is disabled for Layer {}", layer_name);
+            self.event_logger.increment_non_exposure_checks(layer_name);
+        }
+
+        raw
+    }
+
+    #[cfg(feature = "ffi-support")]
+    pub fn log_layer_param_exposure_from_raw(&self, raw: String, param_name: String) {
+        use crate::statsig_types_raw::PartialLayerRaw;
+
+        let partial_raw = match serde_json::from_str::<PartialLayerRaw>(&raw) {
+            Ok(partial_raw) => partial_raw,
+            Err(e) => {
+                log_e!(TAG, "Failed to parse partial layer raw: {}", e);
+                return;
+            }
+        };
+
+        if partial_raw.disable_exposure {
+            self.event_logger
+                .increment_non_exposure_checks(&partial_raw.name);
+            return;
+        }
+
+        let interned_parameter_name = InternedString::from_string(param_name);
+
+        self.event_logger
+            .enqueue(EnqueueExposureOp::layer_param_exposure_from_partial_raw(
+                interned_parameter_name,
+                ExposureTrigger::Auto,
+                partial_raw,
+            ));
+    }
 }
 
 // ------------------------------------------------------------------------------- [ Internal ]
@@ -1980,29 +2298,14 @@ impl Statsig {
             Some(evaluation_options.disable_exposure_logging),
         );
 
-        let data = read_lock_or_else!(self.spec_store.data, {
-            log_error_to_statsig_and_console!(
-                &self.ops_stats,
-                TAG,
-                StatsigErr::LockFailure(
-                    "Failed to acquire read lock for spec store data".to_string()
-                )
-            );
-            return layer;
-        });
-        if let Some(persisted_layer) = self.persistent_values_manager.as_ref().and_then(|p| {
-            let event_logger_ptr = Arc::downgrade(&self.event_logger);
-            p.try_apply_sticky_value_to_layer(
-                &user_internal,
-                &evaluation_options,
-                &layer,
-                Some(event_logger_ptr),
-                disable_exposure_logging,
-                &data,
-            )
-        }) {
-            layer = persisted_layer
-        }
+        layer = PersistentValuesManager::try_apply_sticky_value_to_layer(
+            &self.persistent_values_manager,
+            &user_internal,
+            &evaluation_options,
+            &self.spec_store,
+            &self.ops_stats,
+            layer,
+        );
 
         self.emit_layer_evaluated(&layer);
 
